@@ -1,8 +1,12 @@
-"""django todo"""
-__version__ = '1.4'
+"""
+A multi-user, multi-group task management and assignment system for Django.
+"""
+__version__ = '2.3.1'
 
 __author__ = 'Scot Hacker'
 __email__ = 'shacker@birdhouse.org'
 
 __url__ = 'https://github.com/shacker/django-todo'
 __license__ = 'BSD License'
+
+from . import check
